Learn R Programming

RNRCS (version 0.2.5)

grabNRCS.meta: grabNRCS.meta

Description

A search tool that grabs site level metadata for NRCS networks: SCAN, SNOTEL, SNOTEL-LITE, SNOW, MPRC, and OTHER

Usage

grabNRCS.meta(ntwrks = "SCAN", cnvrt.elev = FALSE)

Arguments

ntwrks

Name(s) of NRCS network(s) to grab metadata for. Options are: 'SCAN','SNTL','SNTLT','SNOW','MPRC','OTHER','COOP','USGS','MSNT','BOR','CLMIND' and/or 'ALL'. If the user enters the term 'ALL,' site level metadata for all networks will be returned. Default is 'SCAN'

cnvrt.elev

Optional. If set to TRUE, the elevation data will be converted from feet to meters. Default is set to FALSE, i.e., elevation data are output in units of feet.

Value

A list of n dataframes comprising the site level metadata for n NRCS networks

References

Downloads <https://www.wcc.nrcs.usda.gov/web_service/AWDB_Web_Service_Reference.htm>

See Also

Currently none

Examples

Run this code
# NOT RUN {
grabNRCS.meta(ntwrks="SCAN")
# }

Run the code above in your browser using DataLab